==> splight_cli-2.3.21-py3-none-any.whl: cli/component/templates/auto_readme.md <==
# {{component_name}} {{component_type}}

## Version: {{version}}

## Table of Contents  
1. [Description](#description)
2. [Input](#Input)
3. [Output](#Output)
4. [Bindings](#Bindings)

### Description

{% if description is not none %}{{description}}{% else %}COMPLETE COMPONENT DESCRIPTION{% endif %}

### Input

{% if inputs is not none -%}
The component's input parameters are:

{% for input in inputs -%}
  - {{input.name}} [{{input.type}}]: (Default: {{input.value}}) {{input.description}}
{% endfor -%}
{%- else -%}
This component does not have any input parameter.
{%- endif %}

### Custom Types

{% if custom_types is not none -%}
The custom types defined by the component are:

{% for item in custom_types -%}
  - {{item.name}}
     {% for p in item.fields -%}
       {{p.name}} [{{p.type}}]: (Default: {{p.value}}) {{p.description}}
     {% endfor %}
{% endfor -%}
{%- else -%}
This component does not have any custom type.
{%- endif -%}

### Output

{% if output is not none -%}
The component's output are:

{% for out in output -%}
  - {{out.name}}:
    {% for field in out.fields -%}
      {{field.name}} [{{field.type}}]
    {% endfor %}
{% endfor %}
{%- else -%}
This component does not have any output.
{%- endif -%}

### Bindings

{% if bindings -%}
{% for val in bindings -%}
  {{loop.index}}. {{val.name}}: The binding **{{val.name}}** is executed when the action **{{val.object_action}}** is applied on a **{{val.object_type}}**.
{% endfor %}
{%- else -%}
This component does not have any binding.
{%- endif %}

### Commands

{% if commands -%}
The component commands are the following:

{% for val in commands -%}
  {{loop.index}}. {{val.name}}: 
    {% for field in val.fields -%}
      {{field.name}} [{{field.type}}]
    {% endfor %}
{% endfor %}
{%- else -%}
This component does not have any command.
{%- endif -%}

### Endpoints

{% if endpoints -%}
The component's endpoints are:

{% for val in endpoints -%}
  {{loop.index}}. Endpoint **{{val.name}}** on port {{val.port}}.
{% endfor %}
{%- else -%}
This component does not have any endpoint
{%- endif -%}

==> splight_cli-3.5.1-py3-none-any.whl: cli/component/templates/auto_readme.md <==
# {{component_name}} {{component_type}}

## Version: {{version}}

## Table of Contents  
1. [Description](#description)
2. [Input](#Input)
3. [Output](#Output)
4. [Bindings](#Bindings)

### Description

{% if description is not none %}{{description}}{% else %}COMPLETE COMPONENT DESCRIPTION{% endif %}

### Input

{% if inputs is not none -%}
The component's input parameters are:

{% for input in inputs -%}
  - {{input.name}} [{{input.type}}]: (Default: {{input.value}}) {{input.description}}
{% endfor -%}
{%- else -%}
This component does not have any input parameter.
{%- endif %}

### Routines

{% if routines is not none -%}
The routines defined by the component are:

{% for routine in routines -%}
  - {{routine.name}}
    Configs:
     {% for p in routine.config -%}
      - {{p.name}} [{{p.type}}]: (Default: {{p.value}}) {{p.description}}
     {% endfor %}
    Inputs:
     {% for p in routine.input -%}
      - {{p.name}} [{{p.type}}] of type [{{p.value_type}}]: (Default: {{p.value}}) {{p.description}}
     {% endfor %}
    Outputs:
     {% for p in routine.output -%}
      - {{p.name}} [{{p.type}}] of type [{{p.value_type}}]: (Default: {{p.value}}) {{p.description}}
     {% endfor %}
{% endfor -%}
{%- else -%}
This component does not have any routines.
{%- endif -%}

### Custom Types

{% if custom_types is not none -%}
The custom types defined by the component are:

{% for item in custom_types -%}
  - {{item.name}}
     {% for p in item.fields -%}
      - {{p.name}} [{{p.type}}]: (Default: {{p.value}}) {{p.description}}
     {% endfor %}
{% endfor -%}
{%- else -%}
This component does not have any custom type.
{%- endif -%}

### Output

{% if output is not none -%}
The component's output are:

{% for out in output -%}
  - {{out.name}}:
    {% for field in out.fields -%}
      - {{field.name}} [{{field.type}}]
    {% endfor %}
{% endfor %}
{%- else -%}
This component does not have any output.
{%- endif -%}

### Bindings

{% if bindings -%}
{% for val in bindings -%}
  {{loop.index}}. {{val.name}}: The binding **{{val.name}}** is executed when the action **{{val.object_action}}** is applied on a **{{val.object_type}}**.
{% endfor %}
{%- else -%}
This component does not have any binding.
{%- endif %}

### Commands

{% if commands -%}
The component commands are the following:

{% for val in commands -%}
  {{loop.index}}. {{val.name}}: 
    {% for field in val.fields -%}
      {{field.name}} [{{field.type}}]
    {% endfor %}
{% endfor %}
{%- else -%}
This component does not have any command.
{%- endif -%}

### Endpoints

{% if endpoints -%}
The component's endpoints are:

{% for val in endpoints -%}
  {{loop.index}}. Endpoint **{{val.name}}** on port {{val.port}}.
{% endfor %}
{%- else -%}
This component does not have any endpoint
{%- endif -%}
